<?php
/**
 * MyBB 1.4
 * Copyright ę 2009 MyBB Group, All Rights Reserved
 *
 * Website: http://www.mybboard.net
  * License: http://www.mybboard.net/about/license
 *
 * $Id$
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

class MYBB_Converter_Module_Polls extends Converter_Module_Polls {

	var $settings = array(
		'friendly_name' => 'ankiet',
		'progress_column' => 'pid',
	);
	
	function import()
	{
		global $mybb, $output, $import_session, $db;

		$this->board->db_connect();

		// Get number of threads
		if(!isset($import_session['total_polls']))
		{
			$query = $this->old_db->simple_select("polls", "COUNT(*) as count");
			$import_session['total_polls'] = $this->old_db->fetch_field($query, 'count');
			$this->old_db->free_result($query);
		}

		if($this->board->check_if_done())
		{
			return "finished";
		}
		
		$output->print_header($this->board->modules[$import_session['module']]['name']);

		// Get number of polls per screen from form
		if(isset($mybb->input['polls_per_screen']))
		{
			$import_session['polls_per_screen'] = intval($mybb->input['polls_per_screen']);
		}
		
		if(empty($import_session['polls_per_screen']))
		{
			$output->print_per_screen_page(1000);
		}
		else
		{
			// A bit of stats to show the progress of the current import
			$output->calculate_stats();
			
			$query = $this->old_db->simple_select("polls", "*", "", array('limit_start' => $import_session['start_polls'], 'limit' => $import_session['polls_per_screen']));
			while($poll = $this->old_db->fetch_array($query))
			{
				$pid = $this->insert($poll);
				
				// Restore connections
				$db->update_query("threads", array('poll' => $pid), "poll = '".(-1 * $poll['pid'])."'");
			}
			
			if($this->old_db->num_rows($query) == 0)
			{
				$output->print_none_left_message();
			}
		}
		$import_session['start_polls'] += $import_session['polls_per_screen'];
		$output->print_footer();
	}
	
	function convert_data($data)
	{
		global $db;
		static $field_info;
		
		if(!isset($field_info))
		{
			// Get columns so we avoid any 'unknown column' errors
			$field_info = $db->show_fields_from("polls");
		}
		
		$insert_data = array();
		
		foreach($field_info as $key => $field)
		{
			if($field['Extra'] == 'auto_increment')
			{
				if($db->type != "sqlite2" && $db->type != "sqlite3")
				{
					$insert_data[$field['Field']] = '';
				}
				continue;
			}

			if(isset($data[$field['Field']]))
			{
				$insert_data[$field['Field']] = $data[$field['Field']];
			}
		}
		
		// MyBB 1.4 values
		$insert_data['import_pid'] = $data['pid'];
		$insert_data['tid'] = $this->get_import->tid($data['tid']);
		
		return $insert_data;
	}
	
	function test()
	{
		// import_tid => tid
		$this->get_import->cache_tids = array(
			7 => 12
		);
		
		$data = array(
			'pid' => 6,
			'tid' => 7,
		);
		
		$match_data = array(
			'import_pid' => 6,
			'tid' => 12,
		);
		
		$this->assert($data, $match_data);
	}
}

?>