<?php
/**
 * MyBB 1.4
 * Copyright © 2009 MyBB Group, All Rights Reserved
 *
 * Website: http://www.mybboard.net
  * License: http://www.mybboard.net/about/license
 *
 * $Id$
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

class MYBB_Converter_Module_Privatemessages extends Converter_Module_Privatemessages {

	var $settings = array(
		'friendly_name' => 'prywatnych wiadomości', 
		'progress_column' => 'pmid',
	);

	function import()
	{
		global $mybb, $output, $import_session, $db;

		$this->board->db_connect();

		// Get number of usergroups
		if(!isset($import_session['total_privatemessages']))
		{
			$query = $this->old_db->simple_select("privatemessages", "COUNT(*) as count");
			$import_session['total_privatemessages'] = $this->old_db->fetch_field($query, 'count');
			$this->old_db->free_result($query);
		}

		if($this->board->check_if_done())
		{
			return "finished";
		}

		$output->print_header($this->board->modules[$import_session['module']]['name']);

		// Get number of posts per screen from form
		if(isset($mybb->input['privatemessages_per_screen']))
		{
			$import_session['privatemessages_per_screen'] = intval($mybb->input['privatemessages_per_screen']);
		}
		
		if(empty($import_session['privatemessages_per_screen']))
		{
			$output->print_per_screen_page(1000);
		}
		else
		{
			// A bit of stats to show the progress of the current import
			$output->calculate_stats();
			
			$query = $this->old_db->simple_select("privatemessages", "*", "", array('limit_start' => $import_session['start_privatemessages'], 'limit' => $import_session['privatemessages_per_screen']));
			
			while($pm = $this->old_db->fetch_array($query))
			{
				$this->insert($pm);
			}
			
			if($this->old_db->num_rows($query) == 0)
			{
				$output->print_none_left_message();
			}
		}
		$import_session['start_privatemessages'] += $import_session['privatemessages_per_screen'];
		$output->print_footer();
	}
	
	function convert_data($data)
	{
		global $db;
		static $field_info;
		
		if(!isset($field_info))
		{
			// Get columns so we avoid any 'unknown column' errors
			$field_info = $db->show_fields_from("privatemessages");
		}
		
		$insert_data = array();
		
		foreach($field_info as $key => $field)
		{
			if($field['Extra'] == 'auto_increment')
			{
				if($db->type != "sqlite2" && $db->type != "sqlite3")
				{
					$insert_data[$field['Field']] = '';
				}
				continue;
			}

			if(isset($data[$field['Field']]))
			{
				$insert_data[$field['Field']] = $data[$field['Field']];
			}
		}
		
		// MyBB 1.4 values
		$insert_data['import_pmid'] = $data['pmid'];
		$insert_data['uid'] = $this->get_import->uid($data['uid']);
		$insert_data['fromid'] = $this->get_import->uid($data['fromid']);
		$insert_data['toid'] = $this->get_import->uid($data['toid']);
		$insert_data['subject'] = encode_to_utf8($data['subject'], "privatemessages", "privatemessages");
		$insert_data['message'] = encode_to_utf8($data['message'], "privatemessages", "privatemessages");
		
		$touserarray = unserialize($data['recipients']);
		
		// Rebuild the recipients array
		$recipients = array();
		if(is_array($touserarray['to']))
		{
			foreach($touserarray['to'] as $key => $uid)
			{	
				$recipients['to'][] = $this->get_import->uid($uid);
			}
		}
		
		if(is_array($touserarray['bcc']))
		{
			foreach($touserarray['bcc'] as $key => $uid)
			{
				$recipients['bcc'][] = $this->get_import->uid($uid);
			}
		}
		$insert_data['recipients'] = serialize($recipients);
		
		return $insert_data;
	}
	
	function test()
	{
		// import_uid => uid
		$this->get_import->cache_uids = array(
			5 => 10,
			6 => 11,
		);
		
		$data = array(
			'pmid' => 1,
			'uid' => 5,
			'fromid' => 5,
			'toid' => 6,
			'recipients' => serialize(array('to' => array(6))),
			'subject' => 'Testéfdfs˙˙',
			'message' => 'Test, test, fdsfdsf ds dsf  estéfdf fdsfds s˙˙'
		);
		
		$match_data = array(
			'import_pmid' => 1,
			'uid' => 10,
			'fromid' => 10,
			'toid' => 11,
			'recipients' => serialize(array('to' => array(11))),
			'subject' => utf8_encode('Testéfdfs˙˙'), // The Merge System should convert the mixed ASCII/Unicode string to proper UTF8
			'message' => utf8_encode('Test, test, fdsfdsf ds dsf  estéfdf fdsfds s˙˙')
		);
		
		$this->assert($data, $match_data);
	}
}

?>