<?php
/**
 * MyBB 1.4
 * Copyright © 2009 MyBB Group, All Rights Reserved
 *
 * Website: http://www.mybboard.net
  * License: http://www.mybboard.net/about/license
 *
 * $Id$
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

class MYBB_Converter_Module_Users extends Converter_Module_Users {

	var $settings = array(
		'friendly_name' => 'użytkowników',
		'progress_column' => 'uid',
		'encode_table' => 'users',
		'postnum_column' => 'postnum',
		'username_column' => 'username',
		'email_column' => 'email',
	);

	function import()
	{
		global $mybb, $output, $import_session, $db;

		$this->board->db_connect();

		// Get number of members
		if(!isset($import_session['total_users']))
		{
			$query = $this->old_db->simple_select("users", "COUNT(*) as count");
			$import_session['total_users'] = $this->old_db->fetch_field($query, 'count');
			$this->old_db->free_result($query);
		}

		if($this->board->check_if_done())
		{
			return "finished";
		}

		$output->print_header($this->board->modules[$import_session['module']]['name']);
		
		// Get number of users per screen from form
		if(isset($mybb->input['users_per_screen']))
		{
			$import_session['users_per_screen'] = intval($mybb->input['users_per_screen']);
		}
		
		if(empty($import_session['users_per_screen']))
		{
			$output->print_per_screen_page(1000);
		}
		else
		{			
			// A bit of stats to show the progress of the current import
			$output->calculate_stats();
			
			// Get members
			$query = $this->old_db->simple_select("users", "*", "", array('order_by' => 'uid', 'order_dir' => 'asc', 'limit_start' => $import_session['start_users'], 'limit' => $import_session['users_per_screen']));
			while($user = $this->old_db->fetch_array($query))
			{
				$this->insert($user);
			}
			
			if($this->old_db->num_rows($query) == 0)
			{
				$output->print_none_left_message();
			}
		}
		$import_session['start_users'] += $import_session['users_per_screen'];
		$output->print_footer();
	}
	
	function convert_data($data)
	{
		global $db;
		static $field_info;
		
		if(!isset($field_info))
		{
			// Get columns so we avoid any 'unknown column' errors
			$field_info = $db->show_fields_from("users");
		}
		
		$insert_data = array();
		
		foreach($field_info as $key => $field)
		{
			if($field['Extra'] == 'auto_increment')
			{
				if($db->type != "sqlite2" && $db->type != "sqlite3")
				{
					$insert_data[$field['Field']] = '';
				}
				continue;
			}

			if(isset($data[$field['Field']]))
			{
				$insert_data[$field['Field']] = $data[$field['Field']];
			}
		}
		
		// MyBB 1.4 values
		$insert_data['import_uid'] = $data['uid'];
		$insert_data['usergroup'] = $this->board->get_group_id($data['usergroup'], array("not_multiple" => true));
		$insert_data['additionalgroups'] = str_replace($insert_data['usergroup'], '', $this->board->get_group_id($data['usergroup']));
		$insert_data['username'] = encode_to_utf8($insert_data['username'], "users", "users");
		$insert_data['signature'] = encode_to_utf8($data['signature'], "users", "users");
		$insert_data['displaygroup'] = $this->board->get_group_id($data['displaygroup'], array("not_multiple" => true));
		$insert_data['import_usergroup'] = $data['usergroup'];
		$insert_data['import_additionalgroups'] = $data['additionalgroups'];
		
		return $insert_data;
	}
	
	function test()
	{
		// import_fid -> fid
		$this->get_import->cache_fids = array(
			5 => 10,
		);
		
		// import_uid -> uid
		$this->get_import->cache_uids = array(
			6 => 11,
		);
		
		$data = array(
			'uid' => 4,
			'usergroup' => 2,
			'username' => 'Testéfdfs˙˙ username',
			'signature' => 'Test, test, fdsfdsf ds dsf  estéfdf fdsfds s˙˙',
			'displaygroup' => 5,
			'additionalgroups' => '4',
		);
		
		$match_data = array(
			'import_uid' => 4,
			'usergroup' => 2,
			'username' => utf8_encode('Testéfdfs˙˙ username'), // The Merge System should convert the mixed ASCII/Unicode string to proper UTF8
			'signature' => utf8_encode('Test, test, fdsfdsf ds dsf  estéfdf fdsfds s˙˙'),
			'displaygroup' => 5,
			'import_usergroup' => 2,
			'import_additionalgroups' => '4',
		);
		
		$this->assert($data, $match_data);
	}
}

?>