<?php
/**
 * MyBB 1.4
 * Copyright © 2009 MyBB Group, All Rights Reserved
 *
 * Website: http://www.mybboard.net
  * License: http://www.mybboard.net/about/license
 *
 * $Id$
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

class PUNBB_Converter_Module_Users extends Converter_Module_Users {

	var $settings = array(
		'friendly_name' => 'użytkowników',
		'progress_column' => 'id',
		'encode_table' => 'users',
		'postnum_column' => 'num_posts',
		'username_column' => 'username',
		'email_column' => 'email',
	);

	function import()
	{
		global $mybb, $output, $import_session, $db;
		
		$this->board->db_connect();
		
		// Get number of members
		if(!isset($import_session['total_users']))
		{
			$query = $this->old_db->simple_select("users", "COUNT(*) as count");
			$import_session['total_users'] = $this->old_db->fetch_field($query, 'count');
			$this->old_db->free_result($query);
		}
		
		if(!isset($import_session['avatar_directory']))
		{
			$query = $this->old_db->simple_select("config", "conf_value, conf_name", "conf_name = 'o_avatars_dir' OR conf_name = 'o_base_url'");
			if($this->old_db->fetch_field($query, 'conf_name') == 'o_avatar_dir')
			{
				$import_session['avatar_directory'] = $this->old_db->fetch_field($query, 'conf_value');
			}
			else
			{
				$import_session['main_directory'] = $this->old_db->fetch_field($query, 'conf_value');
			}
			$this->old_db->free_result($query);
		}

		if($this->board->check_if_done())
		{
			return "finished";
		}
		
		$output->print_header($this->board->modules[$import_session['module']]['name']);
		
		// Get number of users per screen from form
		if(isset($mybb->input['users_per_screen']))
		{
			$import_session['users_per_screen'] = intval($mybb->input['users_per_screen']);
		}
		
		if($import_session['users_per_screen'] == 0)
		{
			$output->print_per_screen_page(1000);
		}
		else
		{
			// A bit of stats to show the progress of the current import
			$output->calculate_stats();
			
			// Get members
			$query = $this->old_db->simple_select("users", "*", "username != 'Guest'", array('order_by' => 'id', 'order_dir' => 'asc', 'limit_start' => $import_session['start_users'], 'limit' => $import_session['users_per_screen']));
			while($user = $this->old_db->fetch_array($query))
			{
				$this->insert($user);
			}
			
			if($this->old_db->num_rows($query) == 0)
			{
				$output->print_none_left_message();
			}
		}
		$import_session['start_users'] += $import_session['users_per_screen'];
		$output->print_footer();
	}
	
	function convert_data($data)
	{
		$insert_data = array();
		
		// punBB values
		$insert_data['usergroup'] = $this->board->get_group_id($data['group_id'], array("not_multiple" => true));
		$insert_data['displaygroup'] = $this->board->get_group_id($data['group_id'], array("not_multiple" => true));
		$insert_data['import_usergroup'] = $this->board->get_group_id($data['group_id'], array("not_multiple" => true, "original" => true));
		$insert_data['import_additionalgroups'] = $this->board->get_group_id($data['group_id'], array("original" => true));
		$insert_data['import_displaygroup'] = $data['group_id'];
		$insert_data['import_uid'] = $data['id'];
		$insert_data['username'] = encode_to_utf8($data['username'], "users", "users");
		$insert_data['email'] = $data['email'];
		$insert_data['regdate'] = $data['registered'];
		$insert_data['lastactive'] = $data['last_visit'];
		$insert_data['lastvisit'] = $data['last_visit'];
		$insert_data['website'] = $data['url'];
		$insert_data['showsigs'] = $data['show_sig'];
		$insert_data['signature'] = encode_to_utf8($data['signature'], "users", "users");
		$insert_data['showavatars'] = $data['show_avatars'];
		$insert_data['timezone'] = str_replace(array('.0', '.00'), array('', ''), $data['timezone']);
		if($data['use_avatar'] == '1')
		{
			$extensions = array('.gif', '.jpg', '.png');
			foreach($extensions as $key => $extension)
			{
				if(file_exists($import_session['main_directory'].'/'.$import_session['avatar_directory'].'/'.$data['id'].$extension))
				{
					list($width, $height) = @getimagesize($import_session['main_directory'].'/'.$import_session['avatar_directory'].'/'.$data['id'].$extension);
					$insert_data['avatardimensions'] = $width.'|'.$height;
					$insert_data['avatartype'] = 'upload';
					$insert_data['avatar'] = $data['id'].$extension;
				}
			}
		}
		
		$insert_data['lastpost'] = $data['last_post'];				
		$insert_data['icq'] = $data['icq'];
		$insert_data['aim'] = $data['aim'];
		$insert_data['yahoo'] = $data['yahoo'];
		$insert_data['msn'] = $data['msn'];
		$insert_data['hideemail'] = $data['email_setting'];
		$insert_data['allownotices'] = $data['notify_with_post'];
		$insert_data['regip'] = $data['registration_ip'];
		$insert_data['passwordconvert'] = $data['password'];
		$insert_data['passwordconverttype'] = 'punbb';
		
		return $insert_data;
	}
}

?>