<?php
/**
 * MyBB 1.4
 * Copyright © 2009 MyBB Group, All Rights Reserved
 *
 * Website: http://www.mybboard.net
  * License: http://www.mybboard.net/about/license
 *
 * $Id$
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

// TODO: Possible bug: vB attachments might be flat file?

class VBULLETIN3_Converter_Module_Attachments extends Converter_Module_Attachments {

	var $settings = array(
		'friendly_name' => 'załączniki',
		'progress_column' => 'attachmentid',
	);

	function import()
	{
		global $mybb, $output, $import_session, $db;

		$this->board->db_connect();

		// Get number of threads
		if(!isset($import_session['total_attachments']))
		{
			$query = $this->old_db->simple_select("attachment", "COUNT(*) as count");
			$import_session['total_attachments'] = $this->old_db->fetch_field($query, 'count');
			$this->old_db->free_result($query);
		}

		if($this->board->check_if_done())
		{
			return "finished";
		}
		
		$output->print_header($this->board->modules[$import_session['module']]['name']);
		
		$this->check_attachments_dir_perms();

		// Get number of polls per screen from form
		if(isset($mybb->input['attachments_per_screen']))
		{
			$import_session['attachments_per_screen'] = intval($mybb->input['attachments_per_screen']);
		}
		
		if(empty($import_session['attachments_per_screen']))
		{
			$output->print_per_screen_page(20);
		}
		else
		{
			// A bit of stats to show the progress of the current import
			$output->calculate_stats();

			$query = $this->old_db->simple_select("attachment", "*", "", array('limit_start' => $import_session['start_attachments'], 'limit' => $import_session['attachments_per_screen']));
			while($attachment = $this->old_db->fetch_array($query))
			{
				$this->insert($attachment);
			}
			
			if($this->old_db->num_rows($query) == 0)
			{
				$output->print_none_left_message();
			}
		}
		$import_session['start_attachments'] += $import_session['attachments_per_screen'];
		$output->print_footer();
	}
	
	function convert_data($data)
	{
		$insert_data = array();
		
		// vBulletin 3 values
		$insert_data['import_aid'] = $data['attachmentid'];				
		$insert_data['filetype'] = $this->get_attach_type($data['extension']);
		
		// Check if it is it an image
		switch(strtolower($insert_data['filetype']))
		{
			case "image/gif":
			case "image/jpeg":
			case "image/x-jpg":
			case "image/x-jpeg":
			case "image/pjpeg":
			case "image/jpg":
			case "image/png":
			case "image/x-png":
				$is_image = 1;
				break;
			default:
				$is_image = 0;
				break;
		}
		
		// Should have thumbnail if it's an image
		if($is_image == 1)
		{
			$insert_data['thumbnail'] = 'SMALL';
		}
		else
		{
			$insert_data['thumbnail'] = '';
		}
		
		$posthash = $this->get_import->post_attachment_details($data['postid']);
		$insert_data['pid'] = $posthash['pid'];
		if($posthash['posthash'])
		{
			$insert_data['posthash'] = $posthash['posthash'];
		}
		else
		{
			mt_srand((double) microtime() * 1000000);
			$insert_data['posthash'] = md5($posthash['tid'].$posthash['uid'].mt_rand());
		}
		
		$insert_data['uid'] = $this->get_import->uid($data['userid']);
		$insert_data['filename'] = $data['filename'];
		$insert_data['attachname'] = "post_".$import_data['uid']."_".$data['dateline'].".attach";
		$insert_data['filesize'] = $data['filesize'];
		$insert_data['downloads'] = $data['counter'];
		$insert_data['visible'] = $data['visible'];
		
		if($data['thumbnail'])
		{
			$insert_data['thumbnail'] = str_replace(".attach", "_thumb.{$data['extension']}", $insert_data['attachname']);
		}
		
		return $insert_data;
	}
	
	function after_insert($data, $insert_data, $aid)
	{
		global $mybb, $db;
		
		if($data['thumbnail'])
		{
			// Transfer attachment thumbnails
			$file = @fopen($mybb->settings['uploadspath'].'/'.$insert_data['thumbnail'], 'w');
			if($file)
			{
				@fwrite($file, $data['thumbnail']);
			}
			else
			{
				$this->board->set_error_notice_in_progress("Nie można przenieść miniatury załącznika (ID: {$aid})");
			}
			@fclose($file);
			@my_chmod($mybb->settings['uploadspath'].'/'.$insert_data['thumbnail'], '0777');
		}
		
		// Transfer attachments
		$file = @fopen($mybb->settings['uploadspath'].'/'.$insert_data['attachname'], 'w');
		if($file)
		{
			@fwrite($file, $data['filedata']);
		}
		else
		{
			$this->board->set_error_notice_in_progress("Nie można przenieść załącznika (ID: {$aid})");
		}
		@fclose($file);
		@my_chmod($mybb->settings['uploadspath'].'/'.$insert_data['attachname'], '0777');
		
		if(!$posthash)
		{
			// Restore connection
			$db->update_query("posts", array('posthash' => $insert_data['posthash']), "pid = '{$insert_data['pid']}'");
		}
	}
	
	/**
	 * Get a attachment mime type from the vB database
	 *
	 * @param string Extension
	 * @return string The mime type
	 */
	function get_attach_type($ext)
	{
		$query = $this->old_db->simple_select("attachmenttype", "mimetype", "extension = '{$ext}'");
		$mimetype = unserialize($this->old_db->fetch_field($query, "mimetype"));
		
		$results = str_replace('Content-type: ', '', $mimetype[0]);
		$this->old_db->free_result($query);
		
		return $results;
	}
}

?>