<?php
/**
 * MyBB 1.4
 * Copyright © 2009 MyBB Group, All Rights Reserved
 *
 * Website: http://www.mybboard.net
  * License: http://www.mybboard.net/about/license
 *
 * $Id$
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

class VBULLETIN3_Converter_Module_Users extends Converter_Module_Users {

	var $settings = array(
		'friendly_name' => 'użytkowników',
		'progress_column' => 'userid',
		'encode_table' => 'user',
		'postnum_column' => 'posts',
		'username_column' => 'username',
		'email_column' => 'email',
	);

	function import()
	{
		global $mybb, $output, $import_session, $db;
		
		$this->board->db_connect();
		
		// Get number of members
		if(!isset($import_session['total_users']))
		{
			$query = $this->old_db->simple_select("user", "COUNT(*) as count");
			$import_session['total_users'] = $this->old_db->fetch_field($query, 'count');
			$this->old_db->free_result($query);
		}
		
		if($this->board->check_if_done())
		{
			return "finished";
		}
		
		$output->print_header($this->board->modules[$import_session['module']]['name']);
		
		// Get number of users per screen from form
		if(isset($mybb->input['users_per_screen']))
		{
			$import_session['users_per_screen'] = intval($mybb->input['users_per_screen']);
		}
		
		if(empty($import_session['users_per_screen']))
		{
			$output->print_per_screen_page(1000);
		}
		else
		{
			// A bit of stats to show the progress of the current import
			$output->calculate_stats();
			
			// Get members
			$query = $this->old_db->simple_select("user", "*", "", array('order_by' => 'userid', 'order_dir' => 'asc', 'limit_start' => $import_session['start_users'], 'limit' => $import_session['users_per_screen']));

			while($user = $this->old_db->fetch_array($query))
			{
				$this->insert($user);
			}
			
			if($this->old_db->num_rows($query) == 0)
			{
				$output->print_none_left_message();
			}
		}
		$import_session['start_users'] += $import_session['users_per_screen'];
		$output->print_footer();
	}
	
	function convert_data($data)
	{
		$insert_data = array();
		
		// vBulletin 3 values
		$insert_data['usergroup'] = $this->board->get_group_id($data['usergroupid'], array("not_multiple" => true));
		$insert_data['additionalgroups'] = str_replace($insert_data['usergroup'], '', $this->board->get_group_id($data['usergroupid']));
		$insert_data['displaygroup'] = $this->board->get_group_id($data['usergroupid'], array("not_multiple" => true));
		$insert_data['import_usergroup'] = $this->board->get_group_id($data['usergroupid'], array("original" => true));
		$insert_data['import_additionalgroups'] = $this->board->get_group_id($data['usergroupid'], array("original" => true));
		$insert_data['import_displaygroup'] = $data['displaygroupid'];
		$insert_data['import_uid'] = $data['userid'];
		$insert_data['username'] = encode_to_utf8($data['username'], "user", "users");
		$insert_data['email'] = $data['email'];
		$insert_data['regdate'] = $data['joindate'];
		$insert_data['lastactive'] = $data['lastactivity'];
		$insert_data['lastvisit'] = $data['lastvisit'];
		$insert_data['website'] = $data['homepage'];
		$avatar = $this->get_avatar($data['avatarid']);
		if(!$avatar)
		{
			$customavatar = $this->get_custom_avatar($data['userid']);
			if(!$customavatar)
			{	
				$insert_data['avatardimensions'] = '';			
				$insert_data['avatar'] = '';
				$insert_data['avatartype'] = '';
			}
		}
		else
		{
			list($width, $height) = @getimagesize($avatar['avatarpath']);
			$insert_data['avatardimensions'] = $width.'|'.$height;			
			$insert_data['avatar'] = $avatar['avatarpath'];
			$insert_data['avatartype'] = 'remote';
		}
		$insert_data['lastpost'] = $data['lastpost'];
		$insert_data['birthday'] = $data['birthday'];
		$insert_data['icq'] = $data['icq'];
		$insert_data['aim'] = $data['aim'];
		$insert_data['yahoo'] = $data['yahoo'];
		$insert_data['msn'] = $data['msn'];				
		$insert_data['timezone'] = str_replace(array('.0', '.00'), array('', ''), $insert_data['timezone']);						
		$insert_data['style'] = 0;				
		$insert_data['referrer'] = $data['referrerid'];				
		$insert_data['regip'] = $data['ipaddress'];				
		$insert_data['totalpms'] = $data['pmtotal'];
		$insert_data['unreadpms'] = $data['pmunread'];
		$insert_data['passwordconvert'] = $data['password'];
		$insert_data['passwordconverttype'] = 'vb3';
		$insert_data['salt'] = $data['salt'];
		$insert_data['signature'] = encode_to_utf8($this->bbcode_parser->convert($this->get_signature($data['userid'])), "user", "users");
		
		return $insert_data;
	}
	
	/**
	 * Get a avatar from the vB database
	 *
	 * @param int Avatar ID
	 * @return array The avatar
	 */
	function get_avatar($aid)
	{
		$aid = intval($aid);
		$query = $this->old_db->simple_select("avatar", "*", "avatarid = '{$aid}'");		
		$results = $this->old_db->fetch_array($query);
		$this->old_db->free_result($query);
		
		return $results;
	}
	
	/**
	 * Get a avatar from the vB database
	 *
	 * @param int Avatar ID
	 * @return array The avatar
	 */
	function get_custom_avatar($uid)
	{
		$uid = intval($uid);
		$query = $this->old_db->simple_select("customavatar", "*", "userid = '{$uid}'");		
		return $this->old_db->fetch_array($query);
	}
	
	/**
	 * Get a signature from a user in the vB database
	 *
	 * @param int User ID
	 * @return array The signature
	 */
	function get_signature($userid)
	{
		$userid = intval($userid);
		$query = $this->old_db->simple_select("usertextfield", "signature", "userid = '{$userid}'", array('limit' => 1));
		return $this->old_db->fetch_field($query, "signature");
	}
}

?>