<?php
/**
 * MyBB 1.4
 * Copyright © 2009 MyBB Group, All Rights Reserved
 *
 * Website: http://www.mybboard.net
  * License: http://www.mybboard.net/about/license
 *
 * $Id$
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

class XMB_Converter_Module_Attachments extends Converter_Module_Attachments {

	var $settings = array(
		'friendly_name' => 'załączniki',
		'progress_column' => 'aid',
	);

	function import()
	{
		global $mybb, $output, $import_session, $db;

		$this->board->db_connect();

		// Get number of threads
		if(!isset($import_session['total_attachments']))
		{
			$query = $this->old_db->simple_select("attachments", "COUNT(*) as count");
			$import_session['total_attachments'] = $this->old_db->fetch_field($query, 'count');
			$this->old_db->free_result($query);
		}
		
		if($this->board->check_if_done())
		{
			return "finished";
		}
		
		$output->print_header($this->board->modules[$import_session['module']]['name']);
		
		// Get number of polls per screen from form
		if(isset($mybb->input['attachments_per_screen']))
		{
			$import_session['attachments_per_screen'] = intval($mybb->input['attachments_per_screen']);
		}
		
		$this->check_attachments_dir_perms();
		
		if(empty($import_session['attachments_per_screen']))
		{
			$output->print_per_screen_page(20);
		}
		else
		{
			// A bit of stats to show the progress of the current import
			$output->calculate_stats();

			$query = $this->old_db->simple_select("attachments", "*", "", array('limit_start' => $import_session['start_attachments'], 'limit' => $import_session['attachments_per_screen']));
			while($attachment = $this->old_db->fetch_array($query))
			{
				$this->insert($attachment);
			}
			
			if($this->old_db->num_rows($query) == 0)
			{
				$output->print_none_left_message();
			}
		}
		$import_session['start_attachments'] += $import_session['attachments_per_screen'];
		$output->print_footer();
	}
	
	function convert_data($data)
	{
		global $db;
		
		$insert_data = array();
		
		// XMB values
		$insert_data['import_aid'] = $data['aid'];
		$insert_data['pid'] = $this->get_import->pid($data['pid']);
		$insert_data['uid'] = $this->get_import->uid($data['uid']);
		$insert_data['filename'] = $data['filename'];
		$insert_data['attachname'] = "post_".$insert_data['uid']."_".time().".attach";
		$insert_data['filetype'] = $data['filetype'];
		$insert_data['filesize'] = $data['filesize'];
		$insert_data['downloads'] = $data['downloads'];

		$posthash = $this->get_import->post_attachment_details($data['pid']);
		$insert_data['pid'] = $posthash['pid'];
		if($posthash['posthash'])
		{
			$insert_data['posthash'] = $posthash['posthash'];
		}
		else
		{
			mt_srand((double) microtime() * 1000000);
			$insert_data['posthash'] = md5($posthash['tid'].$posthash['uid'].mt_rand());
		}
		
		// Check if it is it an image
		switch(strtolower($insert_data['filetype']))
		{
			case "image/gif":
			case "image/jpeg":
			case "image/x-jpg":
			case "image/x-jpeg":
			case "image/pjpeg":
			case "image/jpg":
			case "image/png":
			case "image/x-png":
				$is_image = 1;
				break;
			default:
				$is_image = 0;
				break;
		}
		
		// Should have thumbnail if it's an image
		if($is_image == 1)
		{
			$insert_data['thumbnail'] = 'SMALL';
		}
		else
		{
			$insert_data['thumbnail'] = '';
		}
		
		return $insert_data;
	}
	
	function after_insert($data, $insert_data, $aid)
	{
		global $mybb, $db;
		
		$attachrs = @fopen($mybb->settings['uploadspath'].'/'.$insert_data['attachname'], 'w');
		if($attachrs)
		{
			@fwrite($attachrs, $data['attachment']);
		}
		else
		{
			$this->board->set_error_notice_in_progress("Nie można przenieść załącznika (ID: {$aid})");
		}
		@fclose($attachrs);
		@my_chmod($mybb->settings['uploadspath'].'/'.$insert_data['attachname'], '0777');
		
		if(!$posthash)
		{
			// Restore connection
			$db->update_query("posts", array('posthash' => $insert_data['posthash']), "pid = '{$insert_data['pid']}'");
		}
		
		$db->query("UPDATE ".TABLE_PREFIX."threads SET attachmentcount = attachmentcount + 1 WHERE import_tid = '".$data['tid']."'");
	}
}

?>