<?php
/**
 * MyBB 1.4
 * Copyright © 2009 MyBB Group, All Rights Reserved
 *
 * Website: http://www.mybboard.net
  * License: http://www.mybboard.net/about/license
 *
 * $Id$
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

class XMB_Converter_Module_Threads extends Converter_Module_Threads {

	var $settings = array(
		'friendly_name' => 'wątków',
		'progress_column' => 'tid',
	);
	
	function import()
	{
		global $mybb, $output, $import_session, $db;

		$this->board->db_connect();

		// Get number of threads
		if(!isset($import_session['total_threads']))
		{
			$query = $this->old_db->simple_select("threads", "COUNT(*) as count");
			$import_session['total_threads'] = $this->old_db->fetch_field($query, 'count');
			$this->old_db->free_result($query);
		}
		
		if($this->board->check_if_done())
		{
			return "finished";
		}
		
		$output->print_header($this->board->modules[$import_session['module']]['name']);
		
		// Get number of threads per screen from form
		if(isset($mybb->input['threads_per_screen']))
		{
			$import_session['threads_per_screen'] = intval($mybb->input['threads_per_screen']);
		}
		
		if(empty($import_session['threads_per_screen']))
		{
			$output->print_per_screen_page(1000);
		}
		else
		{
			// A bit of stats to show the progress of the current import
			$output->calculate_stats();
			
			$query = $this->old_db->simple_select("threads", "*", "", array('limit_start' => $import_session['start_threads'], 'limit' => $import_session['threads_per_screen']));
			while($thread = $this->old_db->fetch_array($query))
			{
				$this->insert($thread);
			}
			
			if($this->old_db->num_rows($query) == 0)
			{
				$output->print_none_left_message();
			}
		}
		$import_session['start_threads'] += $import_session['threads_per_screen'];
		$output->print_footer();
	}
	
	function convert_data($data)
	{
		$insert_data = array();
		
		// XMB values
		
		// Check usernames for guests
		if($data['author'] == 'Anonymous')
		{
			$data['author'] = 'Guest';
		}
		
		$insert_data['import_tid'] = $data['tid'];
		$insert_data['sticky'] = $data['topped'];
		$insert_data['fid'] = $this->get_import->fid_f($data['fid']);
		
		$firstpost = $this->get_firstpost($data['tid']);
		$insert_data['firstpost'] = (-1 * intval($firstpost['pid']));
		$insert_data['dateline'] = $firstpost['dateline'];
		$insert_data['subject'] = encode_to_utf8(stripslashes($data['subject']), "threads", "threads");
		
		$insert_data['import_uid'] = $this->board->get_uid($data['author']);
		$insert_data['uid'] = $this->get_import->uid($insert_data['uid']);
		$insert_data['views'] = $data['views'];
		
		if(strpos($data['closed'], 'moved|') !== false)
		{
			$insert_data['closed'] = $data['closed'];
		}
		else
		{
			$insert_data['closed'] = yesno_to_int($data['closed']);
		}
		
		return $insert_data;
	}
	
	/**
	 * Correctly associate any moved threads with their moved thread id. This is automagically run after importing threads.
	 */
	function cleanup()
	{
		global $db;

		$query = $db->simple_select("threads", "tid,closed", "closed LIKE 'moved|%' AND import_tid != '0'");
		while($thread = $db->fetch_array($query))
		{
			$moved_tid = (int)str_replace('moved|', '', $thread['closed']);
			$db->update_query("threads", array('closed' => 'moved|'.$this->get_import->tid($moved_tid)), "tid='{$thread['tid']}'", 1);
		}
	}
	
	/**
	 * Get the first post from a thread in the XMB database
	 *
	 * @param int Thread ID
	 * @return array The first post
	 */
	function get_firstpost($tid)
	{
		$tid = intval($tid);
		$query = $this->old_db->simple_select("posts", "pid,dateline", "tid = '{$tid}'", array('order_by' => 'dateline', 'order_dir' => 'asc', 'limit' => 1));
		$results = $this->old_db->fetch_array($query);
		$this->old_db->free_result($query);
		
		return $results;
	}
}

?>