<?php
/**
 * MyBB 1.4
 * Copyright © 2009 MyBB Group, All Rights Reserved
 *
 * Website: http://www.mybboard.net
  * License: http://www.mybboard.net/about/license
 *
 * $Id$
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

class XMB_Converter_Module_Users extends Converter_Module_Users {

	var $settings = array(
		'friendly_name' => 'użytkowników',
		'progress_column' => 'uid',
		'encode_table' => 'members',
		'postnum_column' => 'postnum',
		'username_column' => 'username',
	);

	function import()
	{
		global $mybb, $output, $import_session, $db;
		
		$this->board->db_connect();
		
		// Get number of members
		if(!isset($import_session['total_users']))
		{
			$query = $this->old_db->simple_select("members", "COUNT(*) as count");
			$import_session['total_users'] = $this->old_db->fetch_field($query, 'count');
			$this->old_db->free_result($query);
		}
		
		if($this->board->check_if_done())
		{
			return "finished";
		}
		
		$output->print_header($this->board->modules[$import_session['module']]['name']);
		
		// Get number of users per screen from form
		if(isset($mybb->input['users_per_screen']))
		{
			$import_session['users_per_screen'] = intval($mybb->input['users_per_screen']);
		}
		
		if(empty($import_session['users_per_screen']))
		{
			$output->print_per_screen_page(1000);
		}
		else
		{
			// A bit of stats to show the progress of the current import
			$output->calculate_stats();
			
			// Get members
			$query = $this->old_db->simple_select("members", "*", "", array('order_by' => 'uid', 'order_dir' => 'asc', 'limit_start' => $import_session['start_users'], 'limit' => $import_session['users_per_screen']));
			while($user = $this->old_db->fetch_array($query))
			{
				$this->insert($user);
			}
			
			if($this->old_db->num_rows($query) == 0)
			{
				$output->print_none_left_message();
			}
		}
		$import_session['start_users'] += $import_session['users_per_screen'];
		$output->print_footer();
	}
	
	function convert_data($data)
	{
		$insert_data = array();
		
		// XMB values
		if($data['status'] == 'Super Administrator')
		{
			$insert_data['usergroup'] = 4;
		}
		else
		{
			$insert_data['usergroup'] = 2;
		}
		
		$insert_data['displaygroup'] = $insert_data['usergroup'];
		$insert_data['import_usergroup'] = $insert_data['usergroup'];
		$insert_data['import_additionalgroups'] = '';
		$insert_data['import_displaygroup'] = $insert_data['usergroup'];
		$insert_data['import_uid'] = $data['uid'];
		$insert_data['username'] = encode_to_utf8($data['username'], "members", "users");
		$insert_data['email'] = $data['email'];
		$insert_data['regdate'] = $data['regdate'];
		$insert_data['lastactive'] = $data['lastvisit'];
		$insert_data['lastvisit'] = $data['lastvisit'];
		$insert_data['website'] = $data['site'];
		list($width, $height) = @getimagesize($data['avatar']);
		$insert_data['avatardimensions'] = $width.'|'.$height;
		$insert_data['avatar'] = $data['avatar'];
		if($insert_data['avatar'] == '')
		{
			$insert_data['avatartype'] = "";
		}
		else
		{
			$insert_data['avatartype'] = 'remote';
		}
		
		if($data['bday'] == '0000-00-00')
		{
			$insert_data['birthday'] = '';
		}
		else
		{
			// MyBB format is in d-m-y
			$bday_values = explode('-', $data['bday']);
			$insert_data['birthday'] = $bday_values[2]."-".$bday_values[1]."-".$bday_values[0];
		}
		$insert_data['icq'] = $data['icq'];
		$insert_data['aim'] = $data['aim'];
		$insert_data['yahoo'] = $data['yahoo'];
		$insert_data['msn'] = $data['msn'];
		$insert_data['hideemail'] = $data['showemail'];
		$insert_data['invisible'] = $data['invisible'];
		$insert_data['ppp'] = $data['ppp'];
		$insert_data['tpp'] = $data['tpp'];
		if($data['timeformat'] == 'dd-mm-yyyy')
		{
			$data['timeformat'] = 'd-m-y';
		}		
		$insert_data['timeformat'] = $data['timeformat'];
		$insert_data['timezone'] = $data['timeoffset'];
		$insert_data['timezone'] = str_replace(array('.0', '.00'), array('', ''), $insert_data['timezone']);
		$insert_data['salt'] = generate_salt();
		$insert_data['password'] = salt_password($data['password'], $insert_data['salt']);
		$insert_data['loginkey'] = generate_loginkey();		
		
		return $insert_data;
	}
}

?>