<?php

class Converter_Module_Posts extends Converter_Module
{
	public $default_values = array(
		'tid' => 0,
		'replyto' => 0,
		'subject' => '',
		'username' => '',
		'fid' => 0,
		'uid' => 0,
		'import_uid' => 0,
		'username' => 0,
		'dateline' => 0,
		'message' => '',
		'ipaddress' => '',
		'longipaddress' => 0,
		'includesig' => 1,
		'smilieoff' => 0,
		'edituid' => 0,
		'edittime' => 0,
		'icon' => 0,
		'visible' => 1,
		'posthash' => '',
	);
	
	/**
	 * Insert post into database
	 *
	 * @param post The insert array going into the MyBB database
	 */
	public function insert($data)
	{
		global $db, $output;
		
		if(WRITE_LOGS == 1)
		{
			$old_data = $data;
		}
		
		$output->print_progress("start", $data[$this->settings['progress_column']]);
		
		$unconverted_values = $data;
		
		// Call our currently module's process function
		$data = $converted_values = $this->convert_data($data);
		
		// Should loop through and fill in any values that aren't set based on the MyBB db schema or other standard default values
		$data = $this->process_default_values($data);

		foreach($data as $key => $value)
		{
			$insert_array[$key] = $db->escape_string($value);
		}
		
		if(WRITE_LOGS == 1)
		{
			global $import_session;
			
			$debug_log = @fopen(MYBB_ROOT."convert/logs/post_debug_data_140_{$import_session['start_date']}.log", 'ab');
			if($debug_log)
			{
				fwrite($debug_log, var_export($insert_array, true));
				@fclose($debug_log);
			}
			
			$debug_log = @fopen(MYBB_ROOT."convert/logs/post_debug_data_oldbb_140_{$import_session['start_date']}.log", 'ab');
			if($debug_log)
			{
				fwrite($debug_log, var_export($old_data, true));
				@fclose($debug_log);
			}
		}
		
		unset($insert_array['import_pid']);
		unset($insert_array['import_uid']);
		
		$db->insert_query("posts", $insert_array);
		$pid = $db->insert_id();
		
		$db->insert_query("post_trackers", array(
			'pid' => intval($pid), 
			'import_pid' => intval($data['import_pid']),
			'import_uid' => intval($data['import_uid'])
		));
		
		$this->cache_posts[$data['import_pid']] = $pid;
		
		if(method_exists($this, "after_import"))
		{
			$this->after_import($unconverted_values, $converted_values, $pid);
		}
		
		$output->print_progress("end");
		
		return $pid;
	}
	
	/**
	 * Rebuild counters, and lastpost information right after importing posts
	 *
	 */
	public function counters_cleanup()
	{
		global $db, $output, $import_session;
		
		$output->print_header("Przebudowa liczników");
		
		$output->construct_progress_bar();
		
		echo "<br />\nPrzebudowywanie liczników wątków, działów i statystyk...(To może chwilę potrwać)<br /><br />\n";
		echo "<br />\nPrzebudowywanie liczników wątków... ";
		flush();
		
		// Rebuild thread counters, forum counters, user post counters, last post* and thread username
		$query = $db->simple_select("threads", "COUNT(*) as count", "import_tid != 0");
		$num_imported_threads = $db->fetch_field($query, "count");
		$progress = $last_percent = 0;
		
		if($import_session['counters_cleanup_start'] < $num_imported_threads)
		{
			$progress = $import_session['counters_cleanup_start'];
			$query = $db->simple_select("threads", "tid", "import_tid != 0", array('order_by' => 'tid', 'order_dir' => 'asc', 'limit_start' => intval($import_session['counters_cleanup_start']), 'limit' => 1000));
			while($thread = $db->fetch_array($query))
			{
				rebuild_thread_counters($thread['tid']);
				
				++$progress;
				
				if(($progress % 5) == 0)
				{
					if(($progress % 100) == 0)
					{
						check_memory();
					}
					$percent = round(($progress/$num_imported_threads)*100, 1);
					if($percent != $last_percent)
					{
						$output->update_progress_bar($percent, "Rebuilding counters for thread #{$thread['tid']}");
					}
					$last_percent = $percent;
				}
			}
			
			$import_session['counters_cleanup_start'] += $progress;
			
			if($import_session['counters_cleanup_start'] >= $num_imported_threads)
			{
				$import_session['counters_cleanup'] = 0;
				echo "done.";
				flush();
				return;
			}
			$import_session['counters_cleanup'] = 1;
			return;
		}
		
		if($import_session['counters_cleanup_start'] >= $num_imported_threads)
		{
			echo "done. <br />Przebudowywanie liczników działów... ";
			flush();
			
			$query = $db->simple_select("forums", "COUNT(*) as count", "import_fid != 0");
			$num_imported_forums = $db->fetch_field($query, "count");
			$progress = 0;
			
			$query = $db->simple_select("forums", "fid", "import_fid != 0", array('order_by' => 'fid', 'order_dir' => 'asc'));
			while($forum = $db->fetch_array($query))
			{
				rebuild_forum_counters($forum['fid']);
				++$progress;
				$output->update_progress_bar(round((($progress/$num_imported_forums)*50), 1)+100, "Rebuilding counters for forum #{$forum['fid']}");
			}
			
			$output->update_progress_bar(150);
			
			$query = $db->simple_select("forums", "fid", "usepostcounts = 0");
			while($forum = $db->fetch_array($query))
			{
				$fids[] = $forum['fid'];
			}
			
			if(is_array($fids))
			{
				$fids = implode(',', $fids);
			}
			
			if($fids)
			{
				$fids = " AND fid NOT IN($fids)";
			}
			else
			{
				$fids = "";
			}
			
			echo "done. <br />Przebudowywanie liczników użytkowników... ";
			flush();
			
			$query = $db->simple_select("users", "COUNT(*) as count", "import_uid != 0");
			$num_imported_users = $db->fetch_field($query, "count");
			$progress = $last_percent = 0;
			
			$query = $db->simple_select("users", "uid", "import_uid != 0");		
			while($user = $db->fetch_array($query))
			{
				$query2 = $db->simple_select("posts", "COUNT(*) AS post_count", "uid='{$user['uid']}' AND visible > 0{$fids}");
				$num_posts = $db->fetch_field($query2, "post_count");
				$db->free_result($query2);
				$db->update_query("users", array("postnum" => intval($num_posts)), "uid='{$user['uid']}'");
				
				++$progress;
				$percent = round((($progress/$num_imported_users)*50)+150, 1);
				if($percent != $last_percent)
				{
					$output->update_progress_bar($percent, "Przebudowywanie licznika dla użytkownika #{$user['uid']}");
				}
				$last_percent = $percent;
			}
			// TODO: recount user posts doesn't seem to work
			
			$output->update_progress_bar(200, "Proszę czekać...");
			
			echo "zakończono.<br />";
			flush();
			
			sleep(3);
		}
	}
}

?>